@@ -7,22 +7,26 @@
 #' @param data Data frame from which variables specified in  \code{formula} are preferentially to be taken.
 #' @param p A percentage of training elements
 #' @param criteria This variable selects the criteria to select the best threshold. The default value is \code{success_rate}.
+#' @param includedata logicals. If TRUE the training and testing datasets are returned.
 #' @param seed a single value, interpreted as an integer, or \code{NULL}. The default value is \code{NULL}, but for future checks of the model or models generated it is advisable to set a random seed to be able to reproduce it.
 #' @param ... arguments passed to \code{\link[e1071]{svm}}
 #'
-#' @return An object of class \code{Optim}. See\code{\link{Optim.object}}
+#' @return An object of class \code{Optim}. See \code{\link{Optim.object}}
 
 #' @examples
-##' if(interactive()){
+#' if(interactive()){
+#'
 #' ## Load a Dataset
 #' data(AustralianCredit)
+#'
 #' ## Generate a model
 #' modelFit <- Optim.SVM(Y~., AustralianCredit, p = 0.7, seed=2018)
 #' modelFit
+#'
 #' }
 #'
 #' @export
-Optim.SVM <- function (formula, data,p, criteria=c("rmse","success","ti_error","tii_error"),seed=NULL, ...){
+Optim.SVM <- function (formula, data,p, criteria=c("rmse","success","ti_error","tii_error"), includedata=FALSE, seed=NULL, ...){
 
   if (!requireNamespace("e1071", quietly = TRUE)) {
     stop(crayon::bold(crayon::red("e1071 package needed for this function to work. Please install it.")),
@@ -72,7 +76,9 @@ Optim.SVM <- function (formula, data,p, criteria=c("rmse","success","ti_error","
               Model=models[models_output$List_Position],
               Predict=predicts[models_output$List_Position],
               Thresholds=thresholds_tested[models_output$List_Position],
-              Confussion_Matrix=mc_threshold[models_output$List_Position])
+              Confussion_Matrix=mc_threshold[models_output$List_Position],
+              Data=ifelse(includedata,list(training,testing),list(NULL))
+   )
    class(ans) <- "Optim"
    return(ans)
 
